==> haskell-direct-sqlite-2.3.26-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-direct-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 direct-sqlite
version:              2.3.26
visibility:           public
id:                   direct-sqlite-2.3.26-ITU8WZTYRnbKS2AfYduhSp
key:                  direct-sqlite-2.3.26-ITU8WZTYRnbKS2AfYduhSp
license:              BSD-3-Clause
copyright:
    Copyright (c) 2012 - 2014 Irene Knapp,
    2014 - 2018 Janne Hellsten,
    2018 - 2020 Sergey Bushnyak

maintainer:           Sergey Bushnyak <sergey.bushnyak@sigrlami.eu>
author:               Irene Knapp <irene.knapp@icloud.com>
homepage:             https://github.com/IreneKnapp/direct-sqlite
synopsis:
    Low-level binding to SQLite3.  Includes UTF8 and BLOB support.

description:
    This package is not very different from the other SQLite3 bindings out
    there, but it fixes a few deficiencies I was finding.  As compared to
    bindings-sqlite3, it is slightly higher-level, in that it supports
    marshalling of data values to and from the database.  In particular,
    it supports strings encoded as UTF8, and BLOBs represented as
    ByteStrings.

category:             Database
abi:                  11fea9051dab186bb7c83c798a067097
exposed:              True
exposed-modules:
    Database.SQLite3 Database.SQLite3.Bindings
    Database.SQLite3.Bindings.Types Database.SQLite3.Direct

import-dirs:          /usr/lib/ghc-9.0.1/site-local/direct-sqlite-2.3.26
library-dirs:         /usr/lib/ghc-9.0.1/site-local/direct-sqlite-2.3.26
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/direct-sqlite-2.3.26
hs-libraries:         HSdirect-sqlite-2.3.26-ITU8WZTYRnbKS2AfYduhSp
extra-libraries:      sqlite3
depends:              base-4.15.0.0 bytestring-0.10.12.1 text-1.2.4.1
haddock-interfaces:
    /usr/share/doc/haskell-direct-sqlite/html/direct-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-direct-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-direct-sqlite-2.3.26-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-direct-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 direct-sqlite
version:              2.3.26
visibility:           public
id:                   direct-sqlite-2.3.26-9bKFR54K97iAceB2FQIVTk
key:                  direct-sqlite-2.3.26-9bKFR54K97iAceB2FQIVTk
license:              BSD-3-Clause
copyright:
    Copyright (c) 2012 - 2014 Irene Knapp,
    2014 - 2018 Janne Hellsten,
    2018 - 2020 Sergey Bushnyak

maintainer:           Sergey Bushnyak <sergey.bushnyak@sigrlami.eu>
author:               Irene Knapp <irene.knapp@icloud.com>
homepage:             https://github.com/IreneKnapp/direct-sqlite
synopsis:
    Low-level binding to SQLite3.  Includes UTF8 and BLOB support.

description:
    This package is not very different from the other SQLite3 bindings out
    there, but it fixes a few deficiencies I was finding.  As compared to
    bindings-sqlite3, it is slightly higher-level, in that it supports
    marshalling of data values to and from the database.  In particular,
    it supports strings encoded as UTF8, and BLOBs represented as
    ByteStrings.

category:             Database
abi:                  aa2d500fb302f520604b43cb0357c002
exposed:              True
exposed-modules:
    Database.SQLite3 Database.SQLite3.Bindings
    Database.SQLite3.Bindings.Types Database.SQLite3.Direct

import-dirs:          /usr/lib/ghc-9.0.1/site-local/direct-sqlite-2.3.26
library-dirs:         /usr/lib/ghc-9.0.1/site-local/direct-sqlite-2.3.26
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/direct-sqlite-2.3.26
hs-libraries:         HSdirect-sqlite-2.3.26-9bKFR54K97iAceB2FQIVTk
extra-libraries:      sqlite3
depends:              base-4.15.0.0 bytestring-0.10.12.1 text-1.2.4.1
haddock-interfaces:
    /usr/share/doc/haskell-direct-sqlite/html/direct-sqlite.haddock

haddock-html:         /usr/share/doc/haskell-direct-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
